#### python3.8.8 32/64位解释器下载地址
> https://mirrors.tuna.tsinghua.edu.cn/anaconda/archive/Anaconda3-2021.11-Windows-x86.exe
> https://mirrors.tuna.tsinghua.edu.cn/anaconda/archive/Anaconda3-2021.11-Windows-x86_64.exe
#### 本项目地址
> https://pypi.org/project/pypcdp